@@ -4,7 +4,7 @@ The Swift-Hohenberg equation
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de> 
 """
 
-from typing import Callable
+from typing import Callable, Optional
 
 import numba as nb
 import numpy as np
@@ -40,7 +40,7 @@ class SwiftHohenbergPDE(PDEBase):
         delta: float = 1.0,
         *,
         bc: BoundariesData = "auto_periodic_neumann",
-        bc_lap: BoundariesData = None,
+        bc_lap: Optional[BoundariesData] = None,
     ):
         r"""
         Args:
