@@ -4,7 +4,6 @@
 
 import os
 import pickle
-from unittest import mock
 
 import numpy as np
 import pytest
@@ -14,6 +13,7 @@ from pde.pdes import AllenCahnPDE, CahnHilliardPDE, DiffusionPDE
 from pde.tools.misc import module_available
 from pde.trackers import get_named_trackers, trackers
 from pde.trackers.base import TrackerBase
+from pde.trackers.interrupts import ConstantInterrupts
 from pde.visualization.movies import Movie
 
 
@@ -60,15 +60,6 @@ def test_simple_progress():
     pbar.finalize()
 
 
-def test_progress_no_tqdm(capsys):
-    """test progress bar without tqdm package"""
-    with mock.patch.dict("sys.modules", {"tqdm": None}):  # @UndefinedVariable
-        with pytest.warns(UserWarning):
-            test_simple_progress()
-    captured = capsys.readouterr()
-    assert len(captured.err) > 0
-
-
 def test_trackers():
     """test whether simple trackers can be used"""
     times = []
@@ -225,3 +216,17 @@ def test_get_named_trackers():
         assert isinstance(name, str)
         tracker = TrackerBase.from_data(name)
         assert isinstance(tracker, cls)
+
+
+def test_double_tracker():
+    """simple test for using a custom tracker twice"""
+    interval = ConstantInterrupts(1)
+    times1, times2 = [], []
+    t1 = trackers.CallbackTracker(lambda s, t: times1.append(t), interval=interval)
+    t2 = trackers.CallbackTracker(lambda s, t: times2.append(t), interval=interval)
+
+    field = ScalarField.random_uniform(UnitGrid([3]))
+    DiffusionPDE().solve(field, t_range=4, dt=0.1, tracker=[t1, t2])
+
+    np.testing.assert_allclose(times1, np.arange(5))
+    np.testing.assert_allclose(times2, np.arange(5))
